@@ -1,4 +1,4 @@
-from .Files import DuckFiles
+from .Dfiles import DuckFiles
 
 # Creamos instancias o funciones directas
 duck = DuckFiles()
